@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -248,7 +248,9 @@ sub mapping {
       [os_freebsd,
        [package => 'cairo']],
       [like_debian,
-       [package => 'libcairo2-dev']]],
+       [package => 'libcairo2-dev']],
+      [os_darwin,
+       [package => 'cairo']]],
 
      [cpanmod => 'CDB::TinyCDB',
       [os_freebsd,
@@ -493,12 +495,16 @@ sub mapping {
       [os_freebsd,
        [package => 'pkgconf']],
       [like_debian,
-       [package => 'pkg-config | pkgconf']]],
+       [package => 'pkg-config | pkgconf']],
+      [os_darwin,
+       [package => 'pkg-config']]],
 
      [cpanmod => 'File::LibMagic',
       # XXX what about freebsd?
       [like_debian,
-       [package => 'libmagic-dev']]],
+       [package => 'libmagic-dev']],
+      [os_darwin,
+       [package => 'libmagic']]],
 
      [cpanmod => 'File::MimeInfo',
       [os_freebsd,
@@ -533,7 +539,7 @@ sub mapping {
 	[package => 'libgd-noxpm-dev | libgd2-xpm-dev']],
        [package => 'libgd-dev']],
       [os_darwin,
-       [package => 'libgd']]],
+       [package => 'gd']]],
 
      [cpanmod => 'Gearman::XS',
       [os_freebsd,
@@ -545,6 +551,15 @@ sub mapping {
      [cpanmod => 'Geo::Hex::V3::XS',
       [package => 'cmake']],
 
+     [cpanmod => 'Geo::Proj4',
+      [os_freebsd,
+       [package => 'libproj4']],
+      [like_debian,
+       [package => 'libproj-dev']],
+      [os_darwin,
+       [package => 'proj']],
+     ],
+      
      [cpanmod => 'Geo::Shapelib',
       [os_freebsd,
        [package => 'shapelib']],
@@ -651,7 +666,7 @@ sub mapping {
        [package => 'libsane-dev']]],
 
      [cpanmod => ['GraphViz', 'GraphViz2::Marpa'],
-      # package named the same in freebsd and debian, maybe everywhere?
+      # package named the same in freebsd, debian and macosx/homebrew, maybe everywhere?
       [package => 'graphviz']],
 
      [cpanmod => 'GSM::Gnokii',
@@ -671,6 +686,12 @@ sub mapping {
       [like_debian,
        [package => 'libgtk-3-dev']]],
 
+     [cpanmod => 'GTop',
+      [os_freebsd,
+       [package => 'libgtop']],
+      [like_debian,
+       [package => 'libgtop2-dev']]],
+
      [cpanmod => 'Heimdal::Kadm5',
       [os_freebsd,
        [package => 'heimdal']],
@@ -1095,7 +1116,9 @@ sub mapping {
       [os_freebsd,
        [package => 'libssh2']],
       [like_debian,
-       [package => 'libssh2-1-dev']]],
+       [package => 'libssh2-1-dev']],
+      # Net-SSH2-0.58 already installs the homebrew package for libssh2 itself
+     ],
 
      [cpanmod => 'Net::WDNS',
       [os_freebsd,
@@ -1146,7 +1169,10 @@ sub mapping {
       [os_freebsd,
        [package => 'pango']],
       [like_debian,
-       [package => 'libpango1.0-dev']]],
+       [package => 'libpango1.0-dev']],
+      [os_darwin,
+       [package => 'pango']],
+     ],
 
      [cpanmod => 'Parallel::Pvm',
       [os_freebsd,
@@ -1556,3 +1582,35 @@ sub mapping {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+CPAN::Plugin::Sysdeps::Mapping - a static mapping of CPAN modules to system packages
+
+=head1 SYNOPSIS
+
+    # Not supposed to be used directly
+
+=head1 DESCRIPTION
+
+=head2 mapping
+
+This function returns a mapping data structure as described in
+L<CPAN::Plugin::Sysdeps/MAPPING>.
+
+As shortcuts (and to avoid typos) a number of constants like
+C<os_freebsd> or C<like_debian> are defined and may be used in the
+mapping data structure.
+
+=head1 AUTHOR
+
+Slaven Rezic
+
+=head1 SEE ALSO
+
+L<CPAN::Plugin::Sysdeps>.
+
+=cut
+
